@@ -91,6 +91,7 @@ def read_csv(file_path):
         return data
     except Exception:
         print("Something went wrong when trying to open the csv file!")
+        print(f" The path to the file was {file_path}")
         sys.exit(2)
 
 
@@ -102,6 +103,8 @@ def create_csv_returning(data):
         csv_writer.writerows(data)
         filepath.seek(0)
     df = read_csv(filepath)
+    df.dropna()
+    df.reset_index(inplace=True)
     return df
 
 
